import { HttpClient } from '@wix/sdk-types';
import { GetListSessionsJobResultOptions, GetListSessionsJobResultResponse, ListSessionsAsyncOptions, ListSessionsAsyncResponse } from './analytics-ng-v1-session-analytics-session.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function listSessionsAsync(httpClient: HttpClient): ListSessionsAsyncSignature;
interface ListSessionsAsyncSignature {
    /**
     * Start an async job to retrieve a list of session IDs, given the specified filters. The following filters **must** be passed:
     * - Time period, either predefined or custom.
     * - Session filter, either navigation flow (page interactions), conversion funnel steps, or device type.
     * @param - Filter options. The following filters **must** be passed:
     *
     * - Time period, either predefined or custom.
     *
     * - Session filter, either navigation flow (page interactions), conversion funnel steps, or device type.
     * @returns List sessions async response.
     */
    (options?: ListSessionsAsyncOptions | undefined): Promise<ListSessionsAsyncResponse>;
}
export declare function getListSessionsJobResult(httpClient: HttpClient): GetListSessionsJobResultSignature;
interface GetListSessionsJobResultSignature {
    /**
     * Retrieves the job status and a list of session IDs, if ready.
     * @param - List sessions job ID.
     * @param - Field options. The `limit` and `offset` filters **must** be passed.
     * @returns Get list sessions job result response.
     */
    (jobId: string, options: GetListSessionsJobResultOptions): Promise<GetListSessionsJobResultResponse>;
}
export declare function markSessionAsRecorded(httpClient: HttpClient): MarkSessionAsRecordedSignature;
interface MarkSessionAsRecordedSignature {
    /**
     * Marks a browser session as recorded.
     * @param - Browser session ID.
     * @returns Mark a browser session as recorded.
     */
    (sessionId: string): Promise<void>;
}
export declare function markRecordingsAsDeleted(httpClient: HttpClient): MarkRecordingsAsDeletedSignature;
interface MarkRecordingsAsDeletedSignature {
    /**
     * Marks browser session recordings as deleted.
     * @param - Browser session IDs.
     * @returns Marks browser session recordings as deleted.
     */
    (sessionIds: string[]): Promise<void>;
}
export { ConversionFunnelSessionsParams, CountFunnelSessionsRequest, CountFunnelSessionsRequestPeriodOneOf, CountFunnelSessionsResponse, CountSessionsRequest, CountSessionsRequestPeriodOneOf, CountSessionsResponse, CustomTimePeriod, DeviceType, FunnelStep, GetListSessionsJobResultOptions, GetListSessionsJobResultRequest, GetListSessionsJobResultResponse, JobResult, JobStatus, ListSessionsAsyncOptions, ListSessionsAsyncOptionsParamsOneOf, ListSessionsAsyncOptionsPeriodOneOf, ListSessionsAsyncRequest, ListSessionsAsyncRequestParamsOneOf, ListSessionsAsyncRequestPeriodOneOf, ListSessionsAsyncResponse, MarkRecordingsAsDeletedRequest, MarkRecordingsAsDeletedResponse, MarkSessionAsRecordedRequest, MarkSessionAsRecordedResponse, NavigationFlowSessionsParams, PredefinedTimePeriod, Recordings, Session, SessionsByDeviceParams, } from './analytics-ng-v1-session-analytics-session.universal.js';
