import { toURLSearchParams } from '@wix/sdk-runtime/rest-modules';
import { resolveUrl } from '@wix/sdk-runtime/rest-modules';
function resolveWixAnalyticsNgSessionIdsV1SessionIdsServiceUrl(opts) {
    const domainToMappings = {
        'bo._base_domain_': [
            {
                srcPath: '/analytics-ng-bo/api',
                destPath: '/api',
            },
            {
                srcPath: '/analytics-ng-bo/v2',
                destPath: '/v2',
            },
        ],
        'wixbo.ai': [
            {
                srcPath: '/analytics-ng-bo/api',
                destPath: '/api',
            },
            {
                srcPath: '/analytics-ng-bo/v2',
                destPath: '/v2',
            },
        ],
        'wix-bo.com': [
            {
                srcPath: '/analytics-ng-bo/api',
                destPath: '/api',
            },
            {
                srcPath: '/analytics-ng-bo/v2',
                destPath: '/v2',
            },
        ],
        'www._base_domain_': [
            {
                srcPath: '/analytics-ng/api',
                destPath: '/api',
            },
            {
                srcPath: '/analytics-ng/report',
                destPath: '/report',
            },
            {
                srcPath: '/analytics-ng/assets',
                destPath: '/assets',
            },
            {
                srcPath: '/analytics-ng/hook',
                destPath: '/hook',
            },
            {
                srcPath: '/analytics-ng/debug-permissions',
                destPath: '/_debug_/permissions',
            },
            {
                srcPath: '/analytics-ng/debug-digest-email',
                destPath: '/debug-digest-email',
            },
            {
                srcPath: '/analytics-ng/utils',
                destPath: '/utils',
            },
            {
                srcPath: '/analytics-ng/v1',
                destPath: '/v1',
            },
            {
                srcPath: '/analytics-ng/v2',
                destPath: '/v2',
            },
            {
                srcPath: '/analytics-ng/debug-partners-digest-email',
                destPath: '/debug-partners-digest-email',
            },
        ],
        'manage._base_domain_': [
            {
                srcPath: '/analytics-ng/api',
                destPath: '/api',
            },
            {
                srcPath: '/analytics-ng/assets',
                destPath: '/assets',
            },
            {
                srcPath: '/analytics-ng/report',
                destPath: '/report',
            },
            {
                srcPath: '/analytics-ng/hook',
                destPath: '/hook',
            },
            {
                srcPath: '/analytics-ng/utils',
                destPath: '/utils',
            },
            {
                srcPath: '/analytics-ng/debug-digest-email',
                destPath: '/debug-digest-email',
            },
            {
                srcPath: '/analytics-ng/subscriptions/off',
                destPath: '/subscriptions/off',
            },
            {
                srcPath: '/analytics-ng/subscriptions/debug/get-unsubscribe-token',
                destPath: '/subscriptions/debug/get-unsubscribe-token',
            },
            {
                srcPath: '/analytics-ng/v1',
                destPath: '/v1',
            },
            {
                srcPath: '/analytics-ng/v2',
                destPath: '/v2',
            },
            {
                srcPath: '/analytics-ng/debug-partners-digest-email',
                destPath: '/debug-partners-digest-email',
            },
            {
                srcPath: '/analytics-ng/v3',
                destPath: '/v3',
            },
            {
                srcPath: '/analytics-ng/v5',
                destPath: '/v5',
            },
            {
                srcPath: '/analytics-ng/v4',
                destPath: '/v4',
            },
        ],
        'api._api_base_domain_': [
            {
                srcPath: '/analytics-ng-server',
                destPath: '',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/analytics/v1/sessions/',
                destPath: '/v1/sessions/',
            },
            {
                srcPath: '/analytics/v2/site-analytics/',
                destPath: '/v2/site-analytics/',
            },
            {
                srcPath: '/analytics/v2/site-analytics',
                destPath: '/v2/site-analytics',
            },
            {
                srcPath: '/analytics/v1/sessions',
                destPath: '/v1/sessions',
            },
            {
                srcPath: '/analytics-ng/v1/sessions',
                destPath: '/v1/sessions',
            },
            {
                srcPath: '/analytics-ng/v2/site-analytics/data',
                destPath: '/v2/site-analytics/data',
            },
        ],
        '*.dev.wix-code.com': [
            {
                srcPath: '/analytics-ng/v2/site-analytics/data',
                destPath: '/v2/site-analytics/data',
            },
            {
                srcPath: '/analytics-ng/v1/sessions',
                destPath: '/v1/sessions',
            },
        ],
        _: [
            {
                srcPath: '/analytics-ng/v2/site-analytics/data',
                destPath: '/v2/site-analytics/data',
            },
            {
                srcPath: '/analytics-ng/v1/sessions',
                destPath: '/v1/sessions',
            },
        ],
    };
    return resolveUrl(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_analytics-session_analytics-session';
/**
 * Start an async job to retrieve a list of session IDs, given the specified filters. The following filters **must** be passed:
 * - Time period, either predefined or custom.
 * - Session filter, either navigation flow (page interactions), conversion funnel steps, or device type.
 */
export function listSessionsAsync(payload) {
    function __listSessionsAsync({ host }) {
        const metadata = {
            entityFqdn: 'wix.analytics_ng.v1.session',
            method: 'POST',
            methodFqn: 'wix.analytics_ng.session_ids.v1.SessionIdsService.ListSessionsAsync',
            packageName: PACKAGE_NAME,
            url: resolveWixAnalyticsNgSessionIdsV1SessionIdsServiceUrl({
                protoPath: '/v1/sessions/list/async',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __listSessionsAsync;
}
/** Retrieves the job status and a list of session IDs, if ready. */
export function getListSessionsJobResult(payload) {
    function __getListSessionsJobResult({ host }) {
        const metadata = {
            entityFqdn: 'wix.analytics_ng.v1.session',
            method: 'GET',
            methodFqn: 'wix.analytics_ng.session_ids.v1.SessionIdsService.GetListSessionsJobResult',
            packageName: PACKAGE_NAME,
            url: resolveWixAnalyticsNgSessionIdsV1SessionIdsServiceUrl({
                protoPath: '/v1/sessions/list/result',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
        };
        return metadata;
    }
    return __getListSessionsJobResult;
}
/** Marks a browser session as recorded. */
export function markSessionAsRecorded(payload) {
    function __markSessionAsRecorded({ host }) {
        const metadata = {
            entityFqdn: 'wix.analytics_ng.v1.session',
            method: 'POST',
            methodFqn: 'wix.analytics_ng.session_ids.v1.SessionIdsService.MarkSessionAsRecorded',
            packageName: PACKAGE_NAME,
            url: resolveWixAnalyticsNgSessionIdsV1SessionIdsServiceUrl({
                protoPath: '/v1/sessions/session-recorded',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __markSessionAsRecorded;
}
/** Marks browser session recordings as deleted. */
export function markRecordingsAsDeleted(payload) {
    function __markRecordingsAsDeleted({ host }) {
        const metadata = {
            entityFqdn: 'wix.analytics_ng.v1.session',
            method: 'POST',
            methodFqn: 'wix.analytics_ng.session_ids.v1.SessionIdsService.MarkRecordingsAsDeleted',
            packageName: PACKAGE_NAME,
            url: resolveWixAnalyticsNgSessionIdsV1SessionIdsServiceUrl({
                protoPath: '/v1/sessions/recordings-deleted',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __markRecordingsAsDeleted;
}
//# sourceMappingURL=analytics-ng-v1-session-analytics-session.http.js.map